@@ -7,6 +7,7 @@ import json
 import logging
 import os
 import random
+import traceback
 from datetime import datetime
 
 import requests
@@ -17,6 +18,7 @@ from lesscode.db.base_sql_helper import BaseSqlHelper, echo_sql
 from lesscode.db.condition_wrapper import ConditionWrapper
 from lesscode.db.connection_info import ConnectionInfo
 from lesscode.db.es.es_pool import EsPool
+from lesscode.db.es.es_request import EsRequest
 from lesscode.db.page import Page
 from lesscode.utils.EsUtil import format_es_param_result
 from lesscode.utils.encryption_algorithm import AES
@@ -167,6 +169,11 @@ class EsHelper:
             "size": size,
             "from": offset,
         }
+        try:
+            if options.correction_param.get("enable"):
+                self.correction_param(params, route_key)
+        except:
+            logging.error(traceback.format_exc())
         if track_total_hits:
             params["track_total_hits"] = track_total_hits
         if param_list:
@@ -184,6 +191,70 @@ class EsHelper:
             logging.info(res)
         return res["hits"]
 
+    def correction_param(self, param, route_key):
+        for k in param:
+            if k in ["terms", "term", "range", "wildcard"]:
+                param[k] = self.correction_field(route_key, param[k], keyword_flag=True)
+            elif k in ["match", "match_phrase"]:
+                param[k] = self.correction_field(route_key, param[k])
+            else:
+                if isinstance(param[k], dict):
+                    self.correction_param(param[k], route_key)
+                elif isinstance(param[k], list):
+                    for i in param[k]:
+                        self.correction_param(i, route_key)
+
+    def correction_field(self, route_key, value, keyword_flag=False):
+        column = list(value.keys())[0]
+        data_value = value[column]
+        column = column.replace(".keyword", "")
+        es_mapping_value = self.get_es_filed_mapping(route_key, column)
+        if es_mapping_value:
+            if es_mapping_value.get("text") and es_mapping_value.get("keyword"):
+                if keyword_flag:
+                    column = f'{column}.keyword'
+        return {
+            column: data_value
+        }
+
+    def get_es_filed_mapping(self, route_key, field):
+        res = self.pool.es_selector_way(url_func_str=self.pool.format_es_field_mapping_url,
+                                        param_dict={"field": field, "route_key": route_key},
+                                        request_way="get").get(route_key, {}).get("mappings", {}).get(
+            field, {}).get("mapping", {}).get(field.split(".")[-1], {})
+        if res.get("fields"):
+            result = {
+                res["type"]: 1,
+                list(res["fields"].values())[0]["type"]: 1
+            }
+        else:
+            result = {
+                res["type"]: 1
+            }
+        return result
+
+    def get_mapping_text_and_keyword_column(self, mapping, reuslt, column=""):
+        for key in mapping:
+            # 获取value的key都有什么是否拥有type和fields
+            value_mapping = mapping[key]
+            if value_mapping.get("type") in ["text", "keyword"] and value_mapping.get("index", True):
+                if value_mapping.get("fields"):
+                    reuslt[f'{column}.{key}' if column else key] = {
+                        "text": 1,
+                        "keyword": 1
+                    }
+                else:
+                    reuslt[f'{column}.{key}' if column else key] = {
+                        value_mapping["type"]: 1
+                    }
+            elif isinstance(value_mapping.get("type"), str):
+                continue
+            else:
+                self.get_mapping_text_and_keyword_column(mapping[key], reuslt,
+                                                         (f'{column}.{key}' if column else key) if key not in [
+                                                             "properties", "fields",
+                                                             "keyword"] else column)
+
     def sync_format_es_return(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10,
                               offset=0,
                               track_total_hits=False, is_need_es_score=False, is_need_decrypt_oralce=False, res=None):
@@ -407,6 +478,7 @@ class EsHelper:
 
     def sync_es_request(self, path, method, params=None, body=None):
         url = self.pool.format_url(path)
+        method = method.lower()
         if method in ["get", "post", "put", "delete"]:
             res = None
             if method == "get":
